# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [1.0.5] - 2018-08-25

### Changed

- Removed `prepublish` script from `package.json`

## [1.0.4] - 2017-08-08

### New

- Added a changelog

### Changed

- Ignore `yarn.lock` and `package-lock.json` files